# coding: utf-8

"""
    Pipelines

    Pipelines represent distinct stages in a workflow, like closing a deal or servicing a support ticket. These endpoints provide access to read and modify pipelines in HubSpot. Pipelines support `deals` and `tickets` object types.  ## Pipeline ID validation  When calling endpoints that take pipelineId as a parameter, that ID must correspond to an existing, un-archived pipeline. Otherwise the request will fail with a `404 Not Found` response.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.pipelines.configuration import Configuration


class Pipeline(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "created_at": "datetime",
        "archived_at": "datetime",
        "archived": "bool",
        "display_order": "int",
        "stages": "list[PipelineStage]",
        "label": "str",
        "id": "str",
        "updated_at": "datetime",
    }

    attribute_map = {
        "created_at": "createdAt",
        "archived_at": "archivedAt",
        "archived": "archived",
        "display_order": "displayOrder",
        "stages": "stages",
        "label": "label",
        "id": "id",
        "updated_at": "updatedAt",
    }

    def __init__(self, created_at=None, archived_at=None, archived=None, display_order=None, stages=None, label=None, id=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """Pipeline - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._archived_at = None
        self._archived = None
        self._display_order = None
        self._stages = None
        self._label = None
        self._id = None
        self._updated_at = None
        self.discriminator = None

        self.created_at = created_at
        if archived_at is not None:
            self.archived_at = archived_at
        self.archived = archived
        self.display_order = display_order
        self.stages = stages
        self.label = label
        self.id = id
        self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this Pipeline.  # noqa: E501

        The date the pipeline was created. The default pipelines will have createdAt = 0.  # noqa: E501

        :return: The created_at of this Pipeline.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Pipeline.

        The date the pipeline was created. The default pipelines will have createdAt = 0.  # noqa: E501

        :param created_at: The created_at of this Pipeline.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def archived_at(self):
        """Gets the archived_at of this Pipeline.  # noqa: E501

        The date the pipeline was archived. `archivedAt` will only be present if the pipeline is archived.  # noqa: E501

        :return: The archived_at of this Pipeline.  # noqa: E501
        :rtype: datetime
        """
        return self._archived_at

    @archived_at.setter
    def archived_at(self, archived_at):
        """Sets the archived_at of this Pipeline.

        The date the pipeline was archived. `archivedAt` will only be present if the pipeline is archived.  # noqa: E501

        :param archived_at: The archived_at of this Pipeline.  # noqa: E501
        :type archived_at: datetime
        """

        self._archived_at = archived_at

    @property
    def archived(self):
        """Gets the archived of this Pipeline.  # noqa: E501

        Whether the pipeline is archived.  # noqa: E501

        :return: The archived of this Pipeline.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this Pipeline.

        Whether the pipeline is archived.  # noqa: E501

        :param archived: The archived of this Pipeline.  # noqa: E501
        :type archived: bool
        """
        if self.local_vars_configuration.client_side_validation and archived is None:  # noqa: E501
            raise ValueError("Invalid value for `archived`, must not be `None`")  # noqa: E501

        self._archived = archived

    @property
    def display_order(self):
        """Gets the display_order of this Pipeline.  # noqa: E501

        The order for displaying this pipeline. If two pipelines have a matching `displayOrder`, they will be sorted alphabetically by label.  # noqa: E501

        :return: The display_order of this Pipeline.  # noqa: E501
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """Sets the display_order of this Pipeline.

        The order for displaying this pipeline. If two pipelines have a matching `displayOrder`, they will be sorted alphabetically by label.  # noqa: E501

        :param display_order: The display_order of this Pipeline.  # noqa: E501
        :type display_order: int
        """
        if self.local_vars_configuration.client_side_validation and display_order is None:  # noqa: E501
            raise ValueError("Invalid value for `display_order`, must not be `None`")  # noqa: E501

        self._display_order = display_order

    @property
    def stages(self):
        """Gets the stages of this Pipeline.  # noqa: E501

        The stages associated with the pipeline. They can be retrieved and updated via the pipeline stages endpoints.  # noqa: E501

        :return: The stages of this Pipeline.  # noqa: E501
        :rtype: list[PipelineStage]
        """
        return self._stages

    @stages.setter
    def stages(self, stages):
        """Sets the stages of this Pipeline.

        The stages associated with the pipeline. They can be retrieved and updated via the pipeline stages endpoints.  # noqa: E501

        :param stages: The stages of this Pipeline.  # noqa: E501
        :type stages: list[PipelineStage]
        """
        if self.local_vars_configuration.client_side_validation and stages is None:  # noqa: E501
            raise ValueError("Invalid value for `stages`, must not be `None`")  # noqa: E501

        self._stages = stages

    @property
    def label(self):
        """Gets the label of this Pipeline.  # noqa: E501

        A unique label used to organize pipelines in HubSpot's UI  # noqa: E501

        :return: The label of this Pipeline.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this Pipeline.

        A unique label used to organize pipelines in HubSpot's UI  # noqa: E501

        :param label: The label of this Pipeline.  # noqa: E501
        :type label: str
        """
        if self.local_vars_configuration.client_side_validation and label is None:  # noqa: E501
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501

        self._label = label

    @property
    def id(self):
        """Gets the id of this Pipeline.  # noqa: E501

        A unique identifier generated by HubSpot that can be used to retrieve and update the pipeline.  # noqa: E501

        :return: The id of this Pipeline.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Pipeline.

        A unique identifier generated by HubSpot that can be used to retrieve and update the pipeline.  # noqa: E501

        :param id: The id of this Pipeline.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def updated_at(self):
        """Gets the updated_at of this Pipeline.  # noqa: E501

        The date the pipeline was last updated.  # noqa: E501

        :return: The updated_at of this Pipeline.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Pipeline.

        The date the pipeline was last updated.  # noqa: E501

        :param updated_at: The updated_at of this Pipeline.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Pipeline):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Pipeline):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pages

    Use these endpoints for interacting with Landing Pages and Site Pages  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.pages.configuration import Configuration


class ContentFolder(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"deleted_at": "datetime", "parent_folder_id": "int", "created": "datetime", "name": "str", "id": "str", "category": "int", "updated": "datetime"}

    attribute_map = {"deleted_at": "deletedAt", "parent_folder_id": "parentFolderId", "created": "created", "name": "name", "id": "id", "category": "category", "updated": "updated"}

    def __init__(self, deleted_at=None, parent_folder_id=None, created=None, name=None, id=None, category=None, updated=None, local_vars_configuration=None):  # noqa: E501
        """ContentFolder - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._deleted_at = None
        self._parent_folder_id = None
        self._created = None
        self._name = None
        self._id = None
        self._category = None
        self._updated = None
        self.discriminator = None

        self.deleted_at = deleted_at
        self.parent_folder_id = parent_folder_id
        self.created = created
        self.name = name
        self.id = id
        self.category = category
        self.updated = updated

    @property
    def deleted_at(self):
        """Gets the deleted_at of this ContentFolder.  # noqa: E501

        The timestamp (ISO8601 format) when this content folder was deleted.  # noqa: E501

        :return: The deleted_at of this ContentFolder.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Sets the deleted_at of this ContentFolder.

        The timestamp (ISO8601 format) when this content folder was deleted.  # noqa: E501

        :param deleted_at: The deleted_at of this ContentFolder.  # noqa: E501
        :type deleted_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and deleted_at is None:  # noqa: E501
            raise ValueError("Invalid value for `deleted_at`, must not be `None`")  # noqa: E501

        self._deleted_at = deleted_at

    @property
    def parent_folder_id(self):
        """Gets the parent_folder_id of this ContentFolder.  # noqa: E501

        The ID of the content folder this folder is nested under  # noqa: E501

        :return: The parent_folder_id of this ContentFolder.  # noqa: E501
        :rtype: int
        """
        return self._parent_folder_id

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id):
        """Sets the parent_folder_id of this ContentFolder.

        The ID of the content folder this folder is nested under  # noqa: E501

        :param parent_folder_id: The parent_folder_id of this ContentFolder.  # noqa: E501
        :type parent_folder_id: int
        """
        if self.local_vars_configuration.client_side_validation and parent_folder_id is None:  # noqa: E501
            raise ValueError("Invalid value for `parent_folder_id`, must not be `None`")  # noqa: E501

        self._parent_folder_id = parent_folder_id

    @property
    def created(self):
        """Gets the created of this ContentFolder.  # noqa: E501


        :return: The created of this ContentFolder.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ContentFolder.


        :param created: The created of this ContentFolder.  # noqa: E501
        :type created: datetime
        """
        if self.local_vars_configuration.client_side_validation and created is None:  # noqa: E501
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def name(self):
        """Gets the name of this ContentFolder.  # noqa: E501

        The name of the folder which will show up in the app dashboard  # noqa: E501

        :return: The name of this ContentFolder.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ContentFolder.

        The name of the folder which will show up in the app dashboard  # noqa: E501

        :param name: The name of this ContentFolder.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def id(self):
        """Gets the id of this ContentFolder.  # noqa: E501

        The unique ID of the content folder.  # noqa: E501

        :return: The id of this ContentFolder.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ContentFolder.

        The unique ID of the content folder.  # noqa: E501

        :param id: The id of this ContentFolder.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def category(self):
        """Gets the category of this ContentFolder.  # noqa: E501

        The type of object this folder applies to. Should always be LANDING_PAGE.  # noqa: E501

        :return: The category of this ContentFolder.  # noqa: E501
        :rtype: int
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ContentFolder.

        The type of object this folder applies to. Should always be LANDING_PAGE.  # noqa: E501

        :param category: The category of this ContentFolder.  # noqa: E501
        :type category: int
        """
        if self.local_vars_configuration.client_side_validation and category is None:  # noqa: E501
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def updated(self):
        """Gets the updated of this ContentFolder.  # noqa: E501


        :return: The updated of this ContentFolder.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this ContentFolder.


        :param updated: The updated of this ContentFolder.  # noqa: E501
        :type updated: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated is None:  # noqa: E501
            raise ValueError("Invalid value for `updated`, must not be `None`")  # noqa: E501

        self._updated = updated

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContentFolder):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ContentFolder):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.crm.owners as api_client
from hubspot.utils.objects import fetch_all
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def owners_api(self) -> api_client.OwnersApi:
        return self._configure_api_client(api_client, "OwnersApi")

    def get_all(self, **kwargs):
        return fetch_all(self.owners_api, **kwargs)



# coding: utf-8

"""
    CMS Source Code

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.source_code.configuration import Configuration


class AssetFileMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"created_at": "int", "archived_at": "int", "folder": "bool", "children": "list[str]", "name": "str", "id": "str", "hash": "str", "updated_at": "int"}

    attribute_map = {"created_at": "createdAt", "archived_at": "archivedAt", "folder": "folder", "children": "children", "name": "name", "id": "id", "hash": "hash", "updated_at": "updatedAt"}

    def __init__(self, created_at=None, archived_at=None, folder=None, children=None, name=None, id=None, hash=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """AssetFileMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._archived_at = None
        self._folder = None
        self._children = None
        self._name = None
        self._id = None
        self._hash = None
        self._updated_at = None
        self.discriminator = None

        self.created_at = created_at
        if archived_at is not None:
            self.archived_at = archived_at
        self.folder = folder
        if children is not None:
            self.children = children
        self.name = name
        self.id = id
        if hash is not None:
            self.hash = hash
        self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this AssetFileMetadata.  # noqa: E501

        Timestamp of when the object was first created.  # noqa: E501

        :return: The created_at of this AssetFileMetadata.  # noqa: E501
        :rtype: int
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AssetFileMetadata.

        Timestamp of when the object was first created.  # noqa: E501

        :param created_at: The created_at of this AssetFileMetadata.  # noqa: E501
        :type created_at: int
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def archived_at(self):
        """Gets the archived_at of this AssetFileMetadata.  # noqa: E501

        Timestamp of when the object was archived (deleted).  # noqa: E501

        :return: The archived_at of this AssetFileMetadata.  # noqa: E501
        :rtype: int
        """
        return self._archived_at

    @archived_at.setter
    def archived_at(self, archived_at):
        """Sets the archived_at of this AssetFileMetadata.

        Timestamp of when the object was archived (deleted).  # noqa: E501

        :param archived_at: The archived_at of this AssetFileMetadata.  # noqa: E501
        :type archived_at: int
        """

        self._archived_at = archived_at

    @property
    def folder(self):
        """Gets the folder of this AssetFileMetadata.  # noqa: E501

        Determines whether or not this path points to a folder.  # noqa: E501

        :return: The folder of this AssetFileMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._folder

    @folder.setter
    def folder(self, folder):
        """Sets the folder of this AssetFileMetadata.

        Determines whether or not this path points to a folder.  # noqa: E501

        :param folder: The folder of this AssetFileMetadata.  # noqa: E501
        :type folder: bool
        """
        if self.local_vars_configuration.client_side_validation and folder is None:  # noqa: E501
            raise ValueError("Invalid value for `folder`, must not be `None`")  # noqa: E501

        self._folder = folder

    @property
    def children(self):
        """Gets the children of this AssetFileMetadata.  # noqa: E501

        If the object is a folder, contains the filenames of the files within the folder.  # noqa: E501

        :return: The children of this AssetFileMetadata.  # noqa: E501
        :rtype: list[str]
        """
        return self._children

    @children.setter
    def children(self, children):
        """Sets the children of this AssetFileMetadata.

        If the object is a folder, contains the filenames of the files within the folder.  # noqa: E501

        :param children: The children of this AssetFileMetadata.  # noqa: E501
        :type children: list[str]
        """

        self._children = children

    @property
    def name(self):
        """Gets the name of this AssetFileMetadata.  # noqa: E501

        The name of the file.  # noqa: E501

        :return: The name of this AssetFileMetadata.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AssetFileMetadata.

        The name of the file.  # noqa: E501

        :param name: The name of this AssetFileMetadata.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def id(self):
        """Gets the id of this AssetFileMetadata.  # noqa: E501

        The path of the file in the CMS Developer File System.  # noqa: E501

        :return: The id of this AssetFileMetadata.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AssetFileMetadata.

        The path of the file in the CMS Developer File System.  # noqa: E501

        :param id: The id of this AssetFileMetadata.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def hash(self):
        """Gets the hash of this AssetFileMetadata.  # noqa: E501


        :return: The hash of this AssetFileMetadata.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this AssetFileMetadata.


        :param hash: The hash of this AssetFileMetadata.  # noqa: E501
        :type hash: str
        """

        self._hash = hash

    @property
    def updated_at(self):
        """Gets the updated_at of this AssetFileMetadata.  # noqa: E501

        Timestamp of when the object was last updated.  # noqa: E501

        :return: The updated_at of this AssetFileMetadata.  # noqa: E501
        :rtype: int
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this AssetFileMetadata.

        Timestamp of when the object was last updated.  # noqa: E501

        :param updated_at: The updated_at of this AssetFileMetadata.  # noqa: E501
        :type updated_at: int
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetFileMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssetFileMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Forms

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.forms.configuration import Configuration


class HubSpotFormConfiguration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "create_new_contact_for_new_email": "bool",
        "editable": "bool",
        "allow_link_to_reset_known_values": "bool",
        "lifecycle_stages": "list[LifecycleStage]",
        "post_submit_action": "FormPostSubmitAction",
        "language": "str",
        "pre_populate_known_values": "bool",
        "cloneable": "bool",
        "notify_contact_owner": "bool",
        "recaptcha_enabled": "bool",
        "archivable": "bool",
        "notify_recipients": "list[str]",
    }

    attribute_map = {
        "create_new_contact_for_new_email": "createNewContactForNewEmail",
        "editable": "editable",
        "allow_link_to_reset_known_values": "allowLinkToResetKnownValues",
        "lifecycle_stages": "lifecycleStages",
        "post_submit_action": "postSubmitAction",
        "language": "language",
        "pre_populate_known_values": "prePopulateKnownValues",
        "cloneable": "cloneable",
        "notify_contact_owner": "notifyContactOwner",
        "recaptcha_enabled": "recaptchaEnabled",
        "archivable": "archivable",
        "notify_recipients": "notifyRecipients",
    }

    def __init__(
        self,
        create_new_contact_for_new_email=None,
        editable=None,
        allow_link_to_reset_known_values=None,
        lifecycle_stages=None,
        post_submit_action=None,
        language=None,
        pre_populate_known_values=None,
        cloneable=None,
        notify_contact_owner=None,
        recaptcha_enabled=None,
        archivable=None,
        notify_recipients=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """HubSpotFormConfiguration - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._create_new_contact_for_new_email = None
        self._editable = None
        self._allow_link_to_reset_known_values = None
        self._lifecycle_stages = None
        self._post_submit_action = None
        self._language = None
        self._pre_populate_known_values = None
        self._cloneable = None
        self._notify_contact_owner = None
        self._recaptcha_enabled = None
        self._archivable = None
        self._notify_recipients = None
        self.discriminator = None

        self.create_new_contact_for_new_email = create_new_contact_for_new_email
        self.editable = editable
        self.allow_link_to_reset_known_values = allow_link_to_reset_known_values
        if lifecycle_stages is not None:
            self.lifecycle_stages = lifecycle_stages
        self.post_submit_action = post_submit_action
        self.language = language
        self.pre_populate_known_values = pre_populate_known_values
        self.cloneable = cloneable
        self.notify_contact_owner = notify_contact_owner
        self.recaptcha_enabled = recaptcha_enabled
        self.archivable = archivable
        self.notify_recipients = notify_recipients

    @property
    def create_new_contact_for_new_email(self):
        """Gets the create_new_contact_for_new_email of this HubSpotFormConfiguration.  # noqa: E501

        Whether to create a new contact when a form is submitted with an email address that doesn’t match any in your existing contacts records.  # noqa: E501

        :return: The create_new_contact_for_new_email of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._create_new_contact_for_new_email

    @create_new_contact_for_new_email.setter
    def create_new_contact_for_new_email(self, create_new_contact_for_new_email):
        """Sets the create_new_contact_for_new_email of this HubSpotFormConfiguration.

        Whether to create a new contact when a form is submitted with an email address that doesn’t match any in your existing contacts records.  # noqa: E501

        :param create_new_contact_for_new_email: The create_new_contact_for_new_email of this HubSpotFormConfiguration.  # noqa: E501
        :type create_new_contact_for_new_email: bool
        """
        if self.local_vars_configuration.client_side_validation and create_new_contact_for_new_email is None:  # noqa: E501
            raise ValueError("Invalid value for `create_new_contact_for_new_email`, must not be `None`")  # noqa: E501

        self._create_new_contact_for_new_email = create_new_contact_for_new_email

    @property
    def editable(self):
        """Gets the editable of this HubSpotFormConfiguration.  # noqa: E501

        Whether the form can be edited.  # noqa: E501

        :return: The editable of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._editable

    @editable.setter
    def editable(self, editable):
        """Sets the editable of this HubSpotFormConfiguration.

        Whether the form can be edited.  # noqa: E501

        :param editable: The editable of this HubSpotFormConfiguration.  # noqa: E501
        :type editable: bool
        """
        if self.local_vars_configuration.client_side_validation and editable is None:  # noqa: E501
            raise ValueError("Invalid value for `editable`, must not be `None`")  # noqa: E501

        self._editable = editable

    @property
    def allow_link_to_reset_known_values(self):
        """Gets the allow_link_to_reset_known_values of this HubSpotFormConfiguration.  # noqa: E501

        Whether to add a reset link to the form. This removes any pre-populated content on the form and creates a new contact on submission.  # noqa: E501

        :return: The allow_link_to_reset_known_values of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._allow_link_to_reset_known_values

    @allow_link_to_reset_known_values.setter
    def allow_link_to_reset_known_values(self, allow_link_to_reset_known_values):
        """Sets the allow_link_to_reset_known_values of this HubSpotFormConfiguration.

        Whether to add a reset link to the form. This removes any pre-populated content on the form and creates a new contact on submission.  # noqa: E501

        :param allow_link_to_reset_known_values: The allow_link_to_reset_known_values of this HubSpotFormConfiguration.  # noqa: E501
        :type allow_link_to_reset_known_values: bool
        """
        if self.local_vars_configuration.client_side_validation and allow_link_to_reset_known_values is None:  # noqa: E501
            raise ValueError("Invalid value for `allow_link_to_reset_known_values`, must not be `None`")  # noqa: E501

        self._allow_link_to_reset_known_values = allow_link_to_reset_known_values

    @property
    def lifecycle_stages(self):
        """Gets the lifecycle_stages of this HubSpotFormConfiguration.  # noqa: E501


        :return: The lifecycle_stages of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: list[LifecycleStage]
        """
        return self._lifecycle_stages

    @lifecycle_stages.setter
    def lifecycle_stages(self, lifecycle_stages):
        """Sets the lifecycle_stages of this HubSpotFormConfiguration.


        :param lifecycle_stages: The lifecycle_stages of this HubSpotFormConfiguration.  # noqa: E501
        :type lifecycle_stages: list[LifecycleStage]
        """

        self._lifecycle_stages = lifecycle_stages

    @property
    def post_submit_action(self):
        """Gets the post_submit_action of this HubSpotFormConfiguration.  # noqa: E501


        :return: The post_submit_action of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: FormPostSubmitAction
        """
        return self._post_submit_action

    @post_submit_action.setter
    def post_submit_action(self, post_submit_action):
        """Sets the post_submit_action of this HubSpotFormConfiguration.


        :param post_submit_action: The post_submit_action of this HubSpotFormConfiguration.  # noqa: E501
        :type post_submit_action: FormPostSubmitAction
        """
        if self.local_vars_configuration.client_side_validation and post_submit_action is None:  # noqa: E501
            raise ValueError("Invalid value for `post_submit_action`, must not be `None`")  # noqa: E501

        self._post_submit_action = post_submit_action

    @property
    def language(self):
        """Gets the language of this HubSpotFormConfiguration.  # noqa: E501

        The language of the form.  # noqa: E501

        :return: The language of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this HubSpotFormConfiguration.

        The language of the form.  # noqa: E501

        :param language: The language of this HubSpotFormConfiguration.  # noqa: E501
        :type language: str
        """
        if self.local_vars_configuration.client_side_validation and language is None:  # noqa: E501
            raise ValueError("Invalid value for `language`, must not be `None`")  # noqa: E501
        allowed_values = [
            "af",
            "ar-eg",
            "bg",
            "bn",
            "ca-es",
            "cs",
            "da",
            "de",
            "el",
            "en",
            "es",
            "es-mx",
            "fi",
            "fr",
            "fr-ca",
            "he-il",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ko",
            "lt",
            "ms",
            "nl",
            "no-no",
            "pl",
            "pt",
            "pt-br",
            "ro",
            "ru",
            "sk",
            "sl",
            "sv",
            "th",
            "tl",
            "tr",
            "uk",
            "vi",
            "zh-cn",
            "zh-hk",
            "zh-tw",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and language not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `language` ({0}), must be one of {1}".format(language, allowed_values))  # noqa: E501

        self._language = language

    @property
    def pre_populate_known_values(self):
        """Gets the pre_populate_known_values of this HubSpotFormConfiguration.  # noqa: E501

        Whether contact fields should pre-populate with known information when a contact returns to your site.  # noqa: E501

        :return: The pre_populate_known_values of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._pre_populate_known_values

    @pre_populate_known_values.setter
    def pre_populate_known_values(self, pre_populate_known_values):
        """Sets the pre_populate_known_values of this HubSpotFormConfiguration.

        Whether contact fields should pre-populate with known information when a contact returns to your site.  # noqa: E501

        :param pre_populate_known_values: The pre_populate_known_values of this HubSpotFormConfiguration.  # noqa: E501
        :type pre_populate_known_values: bool
        """
        if self.local_vars_configuration.client_side_validation and pre_populate_known_values is None:  # noqa: E501
            raise ValueError("Invalid value for `pre_populate_known_values`, must not be `None`")  # noqa: E501

        self._pre_populate_known_values = pre_populate_known_values

    @property
    def cloneable(self):
        """Gets the cloneable of this HubSpotFormConfiguration.  # noqa: E501

        Whether the form can be cloned.  # noqa: E501

        :return: The cloneable of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._cloneable

    @cloneable.setter
    def cloneable(self, cloneable):
        """Sets the cloneable of this HubSpotFormConfiguration.

        Whether the form can be cloned.  # noqa: E501

        :param cloneable: The cloneable of this HubSpotFormConfiguration.  # noqa: E501
        :type cloneable: bool
        """
        if self.local_vars_configuration.client_side_validation and cloneable is None:  # noqa: E501
            raise ValueError("Invalid value for `cloneable`, must not be `None`")  # noqa: E501

        self._cloneable = cloneable

    @property
    def notify_contact_owner(self):
        """Gets the notify_contact_owner of this HubSpotFormConfiguration.  # noqa: E501

        Whether to send a notification email to the contact owner when a submission is received.  # noqa: E501

        :return: The notify_contact_owner of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._notify_contact_owner

    @notify_contact_owner.setter
    def notify_contact_owner(self, notify_contact_owner):
        """Sets the notify_contact_owner of this HubSpotFormConfiguration.

        Whether to send a notification email to the contact owner when a submission is received.  # noqa: E501

        :param notify_contact_owner: The notify_contact_owner of this HubSpotFormConfiguration.  # noqa: E501
        :type notify_contact_owner: bool
        """
        if self.local_vars_configuration.client_side_validation and notify_contact_owner is None:  # noqa: E501
            raise ValueError("Invalid value for `notify_contact_owner`, must not be `None`")  # noqa: E501

        self._notify_contact_owner = notify_contact_owner

    @property
    def recaptcha_enabled(self):
        """Gets the recaptcha_enabled of this HubSpotFormConfiguration.  # noqa: E501

        Whether CAPTCHA (spam prevention) is enabled.  # noqa: E501

        :return: The recaptcha_enabled of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._recaptcha_enabled

    @recaptcha_enabled.setter
    def recaptcha_enabled(self, recaptcha_enabled):
        """Sets the recaptcha_enabled of this HubSpotFormConfiguration.

        Whether CAPTCHA (spam prevention) is enabled.  # noqa: E501

        :param recaptcha_enabled: The recaptcha_enabled of this HubSpotFormConfiguration.  # noqa: E501
        :type recaptcha_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and recaptcha_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `recaptcha_enabled`, must not be `None`")  # noqa: E501

        self._recaptcha_enabled = recaptcha_enabled

    @property
    def archivable(self):
        """Gets the archivable of this HubSpotFormConfiguration.  # noqa: E501

        Whether the form can be archived.  # noqa: E501

        :return: The archivable of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._archivable

    @archivable.setter
    def archivable(self, archivable):
        """Sets the archivable of this HubSpotFormConfiguration.

        Whether the form can be archived.  # noqa: E501

        :param archivable: The archivable of this HubSpotFormConfiguration.  # noqa: E501
        :type archivable: bool
        """
        if self.local_vars_configuration.client_side_validation and archivable is None:  # noqa: E501
            raise ValueError("Invalid value for `archivable`, must not be `None`")  # noqa: E501

        self._archivable = archivable

    @property
    def notify_recipients(self):
        """Gets the notify_recipients of this HubSpotFormConfiguration.  # noqa: E501

        The list of user IDs to receive a notification email when a submission is received.  # noqa: E501

        :return: The notify_recipients of this HubSpotFormConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._notify_recipients

    @notify_recipients.setter
    def notify_recipients(self, notify_recipients):
        """Sets the notify_recipients of this HubSpotFormConfiguration.

        The list of user IDs to receive a notification email when a submission is received.  # noqa: E501

        :param notify_recipients: The notify_recipients of this HubSpotFormConfiguration.  # noqa: E501
        :type notify_recipients: list[str]
        """
        if self.local_vars_configuration.client_side_validation and notify_recipients is None:  # noqa: E501
            raise ValueError("Invalid value for `notify_recipients`, must not be `None`")  # noqa: E501

        self._notify_recipients = notify_recipients

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HubSpotFormConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HubSpotFormConfiguration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Business Units

    Retrieve Business Unit information.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.settings.business_units.configuration import Configuration


class PublicBusinessUnitLogoMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"logo_alt_text": "str", "resized_url": "str", "logo_url": "str"}

    attribute_map = {"logo_alt_text": "logoAltText", "resized_url": "resizedUrl", "logo_url": "logoUrl"}

    def __init__(self, logo_alt_text=None, resized_url=None, logo_url=None, local_vars_configuration=None):  # noqa: E501
        """PublicBusinessUnitLogoMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._logo_alt_text = None
        self._resized_url = None
        self._logo_url = None
        self.discriminator = None

        if logo_alt_text is not None:
            self.logo_alt_text = logo_alt_text
        if resized_url is not None:
            self.resized_url = resized_url
        if logo_url is not None:
            self.logo_url = logo_url

    @property
    def logo_alt_text(self):
        """Gets the logo_alt_text of this PublicBusinessUnitLogoMetadata.  # noqa: E501

        The logo's alt text  # noqa: E501

        :return: The logo_alt_text of this PublicBusinessUnitLogoMetadata.  # noqa: E501
        :rtype: str
        """
        return self._logo_alt_text

    @logo_alt_text.setter
    def logo_alt_text(self, logo_alt_text):
        """Sets the logo_alt_text of this PublicBusinessUnitLogoMetadata.

        The logo's alt text  # noqa: E501

        :param logo_alt_text: The logo_alt_text of this PublicBusinessUnitLogoMetadata.  # noqa: E501
        :type logo_alt_text: str
        """

        self._logo_alt_text = logo_alt_text

    @property
    def resized_url(self):
        """Gets the resized_url of this PublicBusinessUnitLogoMetadata.  # noqa: E501

        The logo's resized url  # noqa: E501

        :return: The resized_url of this PublicBusinessUnitLogoMetadata.  # noqa: E501
        :rtype: str
        """
        return self._resized_url

    @resized_url.setter
    def resized_url(self, resized_url):
        """Sets the resized_url of this PublicBusinessUnitLogoMetadata.

        The logo's resized url  # noqa: E501

        :param resized_url: The resized_url of this PublicBusinessUnitLogoMetadata.  # noqa: E501
        :type resized_url: str
        """

        self._resized_url = resized_url

    @property
    def logo_url(self):
        """Gets the logo_url of this PublicBusinessUnitLogoMetadata.  # noqa: E501

        The logo's url  # noqa: E501

        :return: The logo_url of this PublicBusinessUnitLogoMetadata.  # noqa: E501
        :rtype: str
        """
        return self._logo_url

    @logo_url.setter
    def logo_url(self, logo_url):
        """Sets the logo_url of this PublicBusinessUnitLogoMetadata.

        The logo's url  # noqa: E501

        :param logo_url: The logo_url of this PublicBusinessUnitLogoMetadata.  # noqa: E501
        :type logo_url: str
        """

        self._logo_url = logo_url

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicBusinessUnitLogoMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicBusinessUnitLogoMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Events Send Event Completions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.events.send.configuration import Configuration


class BehavioralEventHttpCompletionRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"occurred_at": "datetime", "event_name": "str", "utk": "str", "uuid": "str", "email": "str", "properties": "dict[str, str]", "object_id": "str"}

    attribute_map = {"occurred_at": "occurredAt", "event_name": "eventName", "utk": "utk", "uuid": "uuid", "email": "email", "properties": "properties", "object_id": "objectId"}

    def __init__(self, occurred_at=None, event_name=None, utk=None, uuid=None, email=None, properties=None, object_id=None, local_vars_configuration=None):  # noqa: E501
        """BehavioralEventHttpCompletionRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._occurred_at = None
        self._event_name = None
        self._utk = None
        self._uuid = None
        self._email = None
        self._properties = None
        self._object_id = None
        self.discriminator = None

        if occurred_at is not None:
            self.occurred_at = occurred_at
        self.event_name = event_name
        if utk is not None:
            self.utk = utk
        if uuid is not None:
            self.uuid = uuid
        if email is not None:
            self.email = email
        if properties is not None:
            self.properties = properties
        if object_id is not None:
            self.object_id = object_id

    @property
    def occurred_at(self):
        """Gets the occurred_at of this BehavioralEventHttpCompletionRequest.  # noqa: E501

        The time when this event occurred. If this isn't set, the current time will be used.  # noqa: E501

        :return: The occurred_at of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._occurred_at

    @occurred_at.setter
    def occurred_at(self, occurred_at):
        """Sets the occurred_at of this BehavioralEventHttpCompletionRequest.

        The time when this event occurred. If this isn't set, the current time will be used.  # noqa: E501

        :param occurred_at: The occurred_at of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :type occurred_at: datetime
        """

        self._occurred_at = occurred_at

    @property
    def event_name(self):
        """Gets the event_name of this BehavioralEventHttpCompletionRequest.  # noqa: E501

        The internal name of the event (`pe<portalID>_eventName`). Can be retrieved through the [event definitions API](https://developers.hubspot.com/docs/reference/api/analytics-and-events/custom-events/custom-event-definitions#get-%2Fevents%2Fv3%2Fevent-definitions) or in [HubSpot's UI](https://knowledge.hubspot.com/reports/create-custom-behavioral-events-with-the-code-wizard#find-internal-name).   # noqa: E501

        :return: The event_name of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this BehavioralEventHttpCompletionRequest.

        The internal name of the event (`pe<portalID>_eventName`). Can be retrieved through the [event definitions API](https://developers.hubspot.com/docs/reference/api/analytics-and-events/custom-events/custom-event-definitions#get-%2Fevents%2Fv3%2Fevent-definitions) or in [HubSpot's UI](https://knowledge.hubspot.com/reports/create-custom-behavioral-events-with-the-code-wizard#find-internal-name).   # noqa: E501

        :param event_name: The event_name of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :type event_name: str
        """
        if self.local_vars_configuration.client_side_validation and event_name is None:  # noqa: E501
            raise ValueError("Invalid value for `event_name`, must not be `None`")  # noqa: E501

        self._event_name = event_name

    @property
    def utk(self):
        """Gets the utk of this BehavioralEventHttpCompletionRequest.  # noqa: E501

        The visitor's usertoken. Used for associating the event data with a CRM record.  # noqa: E501

        :return: The utk of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :rtype: str
        """
        return self._utk

    @utk.setter
    def utk(self, utk):
        """Sets the utk of this BehavioralEventHttpCompletionRequest.

        The visitor's usertoken. Used for associating the event data with a CRM record.  # noqa: E501

        :param utk: The utk of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :type utk: str
        """

        self._utk = utk

    @property
    def uuid(self):
        """Gets the uuid of this BehavioralEventHttpCompletionRequest.  # noqa: E501

        Include a universally unique identifier to assign a unique ID to the event completion. Can be useful for matching data between HubSpot and other external systems.  # noqa: E501

        :return: The uuid of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this BehavioralEventHttpCompletionRequest.

        Include a universally unique identifier to assign a unique ID to the event completion. Can be useful for matching data between HubSpot and other external systems.  # noqa: E501

        :param uuid: The uuid of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :type uuid: str
        """

        self._uuid = uuid

    @property
    def email(self):
        """Gets the email of this BehavioralEventHttpCompletionRequest.  # noqa: E501

        The visitor's email address. Used for associating the event data with a CRM record.  # noqa: E501

        :return: The email of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this BehavioralEventHttpCompletionRequest.

        The visitor's email address. Used for associating the event data with a CRM record.  # noqa: E501

        :param email: The email of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :type email: str
        """

        self._email = email

    @property
    def properties(self):
        """Gets the properties of this BehavioralEventHttpCompletionRequest.  # noqa: E501

        The event properties to update. Takes the format of key-value pairs (property internal name and property value). Learn more about [HubSpot's default event properties](https://developers.hubspot.com/docs/guides/api/analytics-and-events/custom-events/custom-event-definitions#hubspot-s-default-event-properties).  # noqa: E501

        :return: The properties of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this BehavioralEventHttpCompletionRequest.

        The event properties to update. Takes the format of key-value pairs (property internal name and property value). Learn more about [HubSpot's default event properties](https://developers.hubspot.com/docs/guides/api/analytics-and-events/custom-events/custom-event-definitions#hubspot-s-default-event-properties).  # noqa: E501

        :param properties: The properties of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :type properties: dict[str, str]
        """

        self._properties = properties

    @property
    def object_id(self):
        """Gets the object_id of this BehavioralEventHttpCompletionRequest.  # noqa: E501

        The ID of the object that completed the event (e.g., contact ID or visitor ID).  # noqa: E501

        :return: The object_id of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this BehavioralEventHttpCompletionRequest.

        The ID of the object that completed the event (e.g., contact ID or visitor ID).  # noqa: E501

        :param object_id: The object_id of this BehavioralEventHttpCompletionRequest.  # noqa: E501
        :type object_id: str
        """

        self._object_id = object_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BehavioralEventHttpCompletionRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BehavioralEventHttpCompletionRequest):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.crm.extensions.calling.api.channel_connection_settings_api import ChannelConnectionSettingsApi
from hubspot.crm.extensions.calling.api.recording_settings_api import RecordingSettingsApi
from hubspot.crm.extensions.calling.api.settings_api import SettingsApi



# coding: utf-8

# flake8: noqa

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.lists.api.folders_api import FoldersApi
from hubspot.crm.lists.api.lists_api import ListsApi
from hubspot.crm.lists.api.mapping_api import MappingApi
from hubspot.crm.lists.api.memberships_api import MembershipsApi

# import ApiClient
from hubspot.crm.lists.api_client import ApiClient
from hubspot.crm.lists.configuration import Configuration
from hubspot.crm.lists.exceptions import OpenApiException
from hubspot.crm.lists.exceptions import ApiTypeError
from hubspot.crm.lists.exceptions import ApiValueError
from hubspot.crm.lists.exceptions import ApiKeyError
from hubspot.crm.lists.exceptions import ApiAttributeError
from hubspot.crm.lists.exceptions import ApiException

# import models into sdk package
from hubspot.crm.lists.models.api_collection_response_join_time_and_record_id import ApiCollectionResponseJoinTimeAndRecordId
from hubspot.crm.lists.models.api_collection_response_record_list_membership_no_paging import ApiCollectionResponseRecordListMembershipNoPaging
from hubspot.crm.lists.models.error import Error
from hubspot.crm.lists.models.error_detail import ErrorDetail
from hubspot.crm.lists.models.join_time_and_record_id import JoinTimeAndRecordId
from hubspot.crm.lists.models.list_create_request import ListCreateRequest
from hubspot.crm.lists.models.list_create_response import ListCreateResponse
from hubspot.crm.lists.models.list_fetch_response import ListFetchResponse
from hubspot.crm.lists.models.list_filter_update_request import ListFilterUpdateRequest
from hubspot.crm.lists.models.list_folder_create_request import ListFolderCreateRequest
from hubspot.crm.lists.models.list_folder_create_response import ListFolderCreateResponse
from hubspot.crm.lists.models.list_folder_fetch_response import ListFolderFetchResponse
from hubspot.crm.lists.models.list_move_request import ListMoveRequest
from hubspot.crm.lists.models.list_search_request import ListSearchRequest
from hubspot.crm.lists.models.list_search_response import ListSearchResponse
from hubspot.crm.lists.models.list_update_response import ListUpdateResponse
from hubspot.crm.lists.models.lists_by_id_response import ListsByIdResponse
from hubspot.crm.lists.models.membership_change_request import MembershipChangeRequest
from hubspot.crm.lists.models.memberships_update_response import MembershipsUpdateResponse
from hubspot.crm.lists.models.next_page import NextPage
from hubspot.crm.lists.models.paging import Paging
from hubspot.crm.lists.models.previous_page import PreviousPage
from hubspot.crm.lists.models.public_absolute_comparative_timestamp_refine_by import PublicAbsoluteComparativeTimestampRefineBy
from hubspot.crm.lists.models.public_absolute_ranged_timestamp_refine_by import PublicAbsoluteRangedTimestampRefineBy
from hubspot.crm.lists.models.public_ads_search_filter import PublicAdsSearchFilter
from hubspot.crm.lists.models.public_ads_time_filter import PublicAdsTimeFilter
from hubspot.crm.lists.models.public_all_history_refine_by import PublicAllHistoryRefineBy
from hubspot.crm.lists.models.public_all_property_types_operation import PublicAllPropertyTypesOperation
from hubspot.crm.lists.models.public_and_filter_branch import PublicAndFilterBranch
from hubspot.crm.lists.models.public_association_filter_branch import PublicAssociationFilterBranch
from hubspot.crm.lists.models.public_association_in_list_filter import PublicAssociationInListFilter
from hubspot.crm.lists.models.public_batch_migration_mapping import PublicBatchMigrationMapping
from hubspot.crm.lists.models.public_bool_property_operation import PublicBoolPropertyOperation
from hubspot.crm.lists.models.public_calendar_date_property_operation import PublicCalendarDatePropertyOperation
from hubspot.crm.lists.models.public_campaign_influenced_filter import PublicCampaignInfluencedFilter
from hubspot.crm.lists.models.public_communication_subscription_filter import PublicCommunicationSubscriptionFilter
from hubspot.crm.lists.models.public_comparative_date_property_operation import PublicComparativeDatePropertyOperation
from hubspot.crm.lists.models.public_comparative_property_updated_operation import PublicComparativePropertyUpdatedOperation
from hubspot.crm.lists.models.public_constant_filter import PublicConstantFilter
from hubspot.crm.lists.models.public_cta_analytics_filter import PublicCtaAnalyticsFilter
from hubspot.crm.lists.models.public_date_point import PublicDatePoint
from hubspot.crm.lists.models.public_date_property_operation import PublicDatePropertyOperation
from hubspot.crm.lists.models.public_date_time_property_operation import PublicDateTimePropertyOperation
from hubspot.crm.lists.models.public_email_event_filter import PublicEmailEventFilter
from hubspot.crm.lists.models.public_email_subscription_filter import PublicEmailSubscriptionFilter
from hubspot.crm.lists.models.public_enumeration_property_operation import PublicEnumerationPropertyOperation
from hubspot.crm.lists.models.public_event_analytics_filter import PublicEventAnalyticsFilter
from hubspot.crm.lists.models.public_event_filter_metadata import PublicEventFilterMetadata
from hubspot.crm.lists.models.public_fiscal_quarter_reference import PublicFiscalQuarterReference
from hubspot.crm.lists.models.public_fiscal_year_reference import PublicFiscalYearReference
from hubspot.crm.lists.models.public_form_submission_filter import PublicFormSubmissionFilter
from hubspot.crm.lists.models.public_form_submission_filter_coalescing_refine_by import PublicFormSubmissionFilterCoalescingRefineBy
from hubspot.crm.lists.models.public_form_submission_on_page_filter import PublicFormSubmissionOnPageFilter
from hubspot.crm.lists.models.public_in_list_filter import PublicInListFilter
from hubspot.crm.lists.models.public_in_list_filter_metadata import PublicInListFilterMetadata
from hubspot.crm.lists.models.public_index_offset import PublicIndexOffset
from hubspot.crm.lists.models.public_indexed_time_point import PublicIndexedTimePoint
from hubspot.crm.lists.models.public_indexed_time_point_index_reference import PublicIndexedTimePointIndexReference
from hubspot.crm.lists.models.public_integration_event_filter import PublicIntegrationEventFilter
from hubspot.crm.lists.models.public_list_folder import PublicListFolder
from hubspot.crm.lists.models.public_migration_mapping import PublicMigrationMapping
from hubspot.crm.lists.models.public_month_reference import PublicMonthReference
from hubspot.crm.lists.models.public_multi_string_property_operation import PublicMultiStringPropertyOperation
from hubspot.crm.lists.models.public_not_all_filter_branch import PublicNotAllFilterBranch
from hubspot.crm.lists.models.public_not_any_filter_branch import PublicNotAnyFilterBranch
from hubspot.crm.lists.models.public_now_reference import PublicNowReference
from hubspot.crm.lists.models.public_num_associations_filter import PublicNumAssociationsFilter
from hubspot.crm.lists.models.public_num_occurrences_refine_by import PublicNumOccurrencesRefineBy
from hubspot.crm.lists.models.public_number_property_operation import PublicNumberPropertyOperation
from hubspot.crm.lists.models.public_object_list import PublicObjectList
from hubspot.crm.lists.models.public_object_list_search_result import PublicObjectListSearchResult
from hubspot.crm.lists.models.public_or_filter_branch import PublicOrFilterBranch
from hubspot.crm.lists.models.public_page_view_analytics_filter import PublicPageViewAnalyticsFilter
from hubspot.crm.lists.models.public_privacy_analytics_filter import PublicPrivacyAnalyticsFilter
from hubspot.crm.lists.models.public_property_association_filter_branch import PublicPropertyAssociationFilterBranch
from hubspot.crm.lists.models.public_property_association_filter_branch_filter_branches_inner import PublicPropertyAssociationFilterBranchFilterBranchesInner
from hubspot.crm.lists.models.public_property_association_filter_branch_filters_inner import PublicPropertyAssociationFilterBranchFiltersInner
from hubspot.crm.lists.models.public_property_association_in_list_filter import PublicPropertyAssociationInListFilter
from hubspot.crm.lists.models.public_property_filter import PublicPropertyFilter
from hubspot.crm.lists.models.public_property_referenced_time import PublicPropertyReferencedTime
from hubspot.crm.lists.models.public_quarter_reference import PublicQuarterReference
from hubspot.crm.lists.models.public_ranged_date_property_operation import PublicRangedDatePropertyOperation
from hubspot.crm.lists.models.public_ranged_number_property_operation import PublicRangedNumberPropertyOperation
from hubspot.crm.lists.models.public_ranged_time_operation import PublicRangedTimeOperation
from hubspot.crm.lists.models.public_relative_comparative_timestamp_refine_by import PublicRelativeComparativeTimestampRefineBy
from hubspot.crm.lists.models.public_relative_ranged_timestamp_refine_by import PublicRelativeRangedTimestampRefineBy
from hubspot.crm.lists.models.public_restricted_filter_branch import PublicRestrictedFilterBranch
from hubspot.crm.lists.models.public_rolling_date_range_property_operation import PublicRollingDateRangePropertyOperation
from hubspot.crm.lists.models.public_rolling_property_updated_operation import PublicRollingPropertyUpdatedOperation
from hubspot.crm.lists.models.public_set_occurrences_refine_by import PublicSetOccurrencesRefineBy
from hubspot.crm.lists.models.public_string_property_operation import PublicStringPropertyOperation
from hubspot.crm.lists.models.public_survey_monkey_filter import PublicSurveyMonkeyFilter
from hubspot.crm.lists.models.public_survey_monkey_value_filter import PublicSurveyMonkeyValueFilter
from hubspot.crm.lists.models.public_survey_monkey_value_filter_value_comparison import PublicSurveyMonkeyValueFilterValueComparison
from hubspot.crm.lists.models.public_time_offset import PublicTimeOffset
from hubspot.crm.lists.models.public_time_point_operation import PublicTimePointOperation
from hubspot.crm.lists.models.public_time_point_operation_time_point import PublicTimePointOperationTimePoint
from hubspot.crm.lists.models.public_today_reference import PublicTodayReference
from hubspot.crm.lists.models.public_unified_events_filter import PublicUnifiedEventsFilter
from hubspot.crm.lists.models.public_unified_events_filter_branch import PublicUnifiedEventsFilterBranch
from hubspot.crm.lists.models.public_webinar_filter import PublicWebinarFilter
from hubspot.crm.lists.models.public_week_reference import PublicWeekReference
from hubspot.crm.lists.models.public_year_reference import PublicYearReference
from hubspot.crm.lists.models.record_list_membership import RecordListMembership



import hubspot.marketing.transactional as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def public_smtp_tokens_api(self) -> api_client.PublicSMTPTokensApi:
        return self._configure_api_client(api_client, "PublicSMTPTokensApi")

    @property
    def single_send_api(self) -> api_client.SingleSendApi:
        return self._configure_api_client(api_client, "SingleSendApi")



# coding: utf-8

"""
    Pages

    Use these endpoints for interacting with Landing Pages and Site Pages  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.pages.configuration import Configuration


class Gradient(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"angle": "Angle", "side_or_corner": "SideOrCorner", "colors": "list[ColorStop]"}

    attribute_map = {"angle": "angle", "side_or_corner": "sideOrCorner", "colors": "colors"}

    def __init__(self, angle=None, side_or_corner=None, colors=None, local_vars_configuration=None):  # noqa: E501
        """Gradient - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._angle = None
        self._side_or_corner = None
        self._colors = None
        self.discriminator = None

        self.angle = angle
        self.side_or_corner = side_or_corner
        self.colors = colors

    @property
    def angle(self):
        """Gets the angle of this Gradient.  # noqa: E501


        :return: The angle of this Gradient.  # noqa: E501
        :rtype: Angle
        """
        return self._angle

    @angle.setter
    def angle(self, angle):
        """Sets the angle of this Gradient.


        :param angle: The angle of this Gradient.  # noqa: E501
        :type angle: Angle
        """
        if self.local_vars_configuration.client_side_validation and angle is None:  # noqa: E501
            raise ValueError("Invalid value for `angle`, must not be `None`")  # noqa: E501

        self._angle = angle

    @property
    def side_or_corner(self):
        """Gets the side_or_corner of this Gradient.  # noqa: E501


        :return: The side_or_corner of this Gradient.  # noqa: E501
        :rtype: SideOrCorner
        """
        return self._side_or_corner

    @side_or_corner.setter
    def side_or_corner(self, side_or_corner):
        """Sets the side_or_corner of this Gradient.


        :param side_or_corner: The side_or_corner of this Gradient.  # noqa: E501
        :type side_or_corner: SideOrCorner
        """
        if self.local_vars_configuration.client_side_validation and side_or_corner is None:  # noqa: E501
            raise ValueError("Invalid value for `side_or_corner`, must not be `None`")  # noqa: E501

        self._side_or_corner = side_or_corner

    @property
    def colors(self):
        """Gets the colors of this Gradient.  # noqa: E501

          # noqa: E501

        :return: The colors of this Gradient.  # noqa: E501
        :rtype: list[ColorStop]
        """
        return self._colors

    @colors.setter
    def colors(self, colors):
        """Sets the colors of this Gradient.

          # noqa: E501

        :param colors: The colors of this Gradient.  # noqa: E501
        :type colors: list[ColorStop]
        """
        if self.local_vars_configuration.client_side_validation and colors is None:  # noqa: E501
            raise ValueError("Invalid value for `colors`, must not be `None`")  # noqa: E501

        self._colors = colors

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Gradient):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Gradient):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Marketing Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.events.configuration import Configuration


class ParticipationProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"occurred_at": "int", "attendance_percentage": "str", "attendance_state": "str", "attendance_duration_seconds": "int"}

    attribute_map = {"occurred_at": "occurredAt", "attendance_percentage": "attendancePercentage", "attendance_state": "attendanceState", "attendance_duration_seconds": "attendanceDurationSeconds"}

    def __init__(self, occurred_at=None, attendance_percentage=None, attendance_state=None, attendance_duration_seconds=None, local_vars_configuration=None):  # noqa: E501
        """ParticipationProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._occurred_at = None
        self._attendance_percentage = None
        self._attendance_state = None
        self._attendance_duration_seconds = None
        self.discriminator = None

        self.occurred_at = occurred_at
        if attendance_percentage is not None:
            self.attendance_percentage = attendance_percentage
        self.attendance_state = attendance_state
        if attendance_duration_seconds is not None:
            self.attendance_duration_seconds = attendance_duration_seconds

    @property
    def occurred_at(self):
        """Gets the occurred_at of this ParticipationProperties.  # noqa: E501


        :return: The occurred_at of this ParticipationProperties.  # noqa: E501
        :rtype: int
        """
        return self._occurred_at

    @occurred_at.setter
    def occurred_at(self, occurred_at):
        """Sets the occurred_at of this ParticipationProperties.


        :param occurred_at: The occurred_at of this ParticipationProperties.  # noqa: E501
        :type occurred_at: int
        """
        if self.local_vars_configuration.client_side_validation and occurred_at is None:  # noqa: E501
            raise ValueError("Invalid value for `occurred_at`, must not be `None`")  # noqa: E501

        self._occurred_at = occurred_at

    @property
    def attendance_percentage(self):
        """Gets the attendance_percentage of this ParticipationProperties.  # noqa: E501


        :return: The attendance_percentage of this ParticipationProperties.  # noqa: E501
        :rtype: str
        """
        return self._attendance_percentage

    @attendance_percentage.setter
    def attendance_percentage(self, attendance_percentage):
        """Sets the attendance_percentage of this ParticipationProperties.


        :param attendance_percentage: The attendance_percentage of this ParticipationProperties.  # noqa: E501
        :type attendance_percentage: str
        """

        self._attendance_percentage = attendance_percentage

    @property
    def attendance_state(self):
        """Gets the attendance_state of this ParticipationProperties.  # noqa: E501


        :return: The attendance_state of this ParticipationProperties.  # noqa: E501
        :rtype: str
        """
        return self._attendance_state

    @attendance_state.setter
    def attendance_state(self, attendance_state):
        """Sets the attendance_state of this ParticipationProperties.


        :param attendance_state: The attendance_state of this ParticipationProperties.  # noqa: E501
        :type attendance_state: str
        """
        if self.local_vars_configuration.client_side_validation and attendance_state is None:  # noqa: E501
            raise ValueError("Invalid value for `attendance_state`, must not be `None`")  # noqa: E501
        allowed_values = ["REGISTERED", "ATTENDED", "CANCELLED", "EMPTY", "NO_SHOW"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and attendance_state not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `attendance_state` ({0}), must be one of {1}".format(attendance_state, allowed_values))  # noqa: E501

        self._attendance_state = attendance_state

    @property
    def attendance_duration_seconds(self):
        """Gets the attendance_duration_seconds of this ParticipationProperties.  # noqa: E501


        :return: The attendance_duration_seconds of this ParticipationProperties.  # noqa: E501
        :rtype: int
        """
        return self._attendance_duration_seconds

    @attendance_duration_seconds.setter
    def attendance_duration_seconds(self, attendance_duration_seconds):
        """Sets the attendance_duration_seconds of this ParticipationProperties.


        :param attendance_duration_seconds: The attendance_duration_seconds of this ParticipationProperties.  # noqa: E501
        :type attendance_duration_seconds: int
        """

        self._attendance_duration_seconds = attendance_duration_seconds

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParticipationProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ParticipationProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cms Content Audit

    Use this endpoint to query audit logs of CMS changes that occurred on your HubSpot account.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.audit_logs.configuration import Configuration


class PublicAuditLog(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"meta": "object", "object_name": "str", "full_name": "str", "event": "str", "user_id": "str", "object_id": "str", "object_type": "str", "timestamp": "datetime"}

    attribute_map = {
        "meta": "meta",
        "object_name": "objectName",
        "full_name": "fullName",
        "event": "event",
        "user_id": "userId",
        "object_id": "objectId",
        "object_type": "objectType",
        "timestamp": "timestamp",
    }

    def __init__(self, meta=None, object_name=None, full_name=None, event=None, user_id=None, object_id=None, object_type=None, timestamp=None, local_vars_configuration=None):  # noqa: E501
        """PublicAuditLog - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._meta = None
        self._object_name = None
        self._full_name = None
        self._event = None
        self._user_id = None
        self._object_id = None
        self._object_type = None
        self._timestamp = None
        self.discriminator = None

        if meta is not None:
            self.meta = meta
        self.object_name = object_name
        self.full_name = full_name
        self.event = event
        self.user_id = user_id
        self.object_id = object_id
        self.object_type = object_type
        self.timestamp = timestamp

    @property
    def meta(self):
        """Gets the meta of this PublicAuditLog.  # noqa: E501


        :return: The meta of this PublicAuditLog.  # noqa: E501
        :rtype: object
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this PublicAuditLog.


        :param meta: The meta of this PublicAuditLog.  # noqa: E501
        :type meta: object
        """

        self._meta = meta

    @property
    def object_name(self):
        """Gets the object_name of this PublicAuditLog.  # noqa: E501

        The internal name of the object in HubSpot.  # noqa: E501

        :return: The object_name of this PublicAuditLog.  # noqa: E501
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """Sets the object_name of this PublicAuditLog.

        The internal name of the object in HubSpot.  # noqa: E501

        :param object_name: The object_name of this PublicAuditLog.  # noqa: E501
        :type object_name: str
        """
        if self.local_vars_configuration.client_side_validation and object_name is None:  # noqa: E501
            raise ValueError("Invalid value for `object_name`, must not be `None`")  # noqa: E501

        self._object_name = object_name

    @property
    def full_name(self):
        """Gets the full_name of this PublicAuditLog.  # noqa: E501

        The name of the user who caused the event.  # noqa: E501

        :return: The full_name of this PublicAuditLog.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this PublicAuditLog.

        The name of the user who caused the event.  # noqa: E501

        :param full_name: The full_name of this PublicAuditLog.  # noqa: E501
        :type full_name: str
        """
        if self.local_vars_configuration.client_side_validation and full_name is None:  # noqa: E501
            raise ValueError("Invalid value for `full_name`, must not be `None`")  # noqa: E501

        self._full_name = full_name

    @property
    def event(self):
        """Gets the event of this PublicAuditLog.  # noqa: E501

        The type of event that took place (CREATED, UPDATED, PUBLISHED, DELETED, UNPUBLISHED).  # noqa: E501

        :return: The event of this PublicAuditLog.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this PublicAuditLog.

        The type of event that took place (CREATED, UPDATED, PUBLISHED, DELETED, UNPUBLISHED).  # noqa: E501

        :param event: The event of this PublicAuditLog.  # noqa: E501
        :type event: str
        """
        if self.local_vars_configuration.client_side_validation and event is None:  # noqa: E501
            raise ValueError("Invalid value for `event`, must not be `None`")  # noqa: E501
        allowed_values = ["CREATED", "UPDATED", "PUBLISHED", "DELETED", "UNPUBLISHED", "RESTORE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `event` ({0}), must be one of {1}".format(event, allowed_values))  # noqa: E501

        self._event = event

    @property
    def user_id(self):
        """Gets the user_id of this PublicAuditLog.  # noqa: E501

        The ID of the user who caused the event.  # noqa: E501

        :return: The user_id of this PublicAuditLog.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PublicAuditLog.

        The ID of the user who caused the event.  # noqa: E501

        :param user_id: The user_id of this PublicAuditLog.  # noqa: E501
        :type user_id: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def object_id(self):
        """Gets the object_id of this PublicAuditLog.  # noqa: E501

        The ID of the object.  # noqa: E501

        :return: The object_id of this PublicAuditLog.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this PublicAuditLog.

        The ID of the object.  # noqa: E501

        :param object_id: The object_id of this PublicAuditLog.  # noqa: E501
        :type object_id: str
        """
        if self.local_vars_configuration.client_side_validation and object_id is None:  # noqa: E501
            raise ValueError("Invalid value for `object_id`, must not be `None`")  # noqa: E501

        self._object_id = object_id

    @property
    def object_type(self):
        """Gets the object_type of this PublicAuditLog.  # noqa: E501

        The type of the object (BLOG, LANDING_PAGE, DOMAIN, HUBDB_TABLE etc.)  # noqa: E501

        :return: The object_type of this PublicAuditLog.  # noqa: E501
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this PublicAuditLog.

        The type of the object (BLOG, LANDING_PAGE, DOMAIN, HUBDB_TABLE etc.)  # noqa: E501

        :param object_type: The object_type of this PublicAuditLog.  # noqa: E501
        :type object_type: str
        """
        if self.local_vars_configuration.client_side_validation and object_type is None:  # noqa: E501
            raise ValueError("Invalid value for `object_type`, must not be `None`")  # noqa: E501
        allowed_values = [
            "BLOG",
            "BLOG_POST",
            "LANDING_PAGE",
            "WEBSITE_PAGE",
            "TEMPLATE",
            "MODULE",
            "GLOBAL_MODULE",
            "SERVERLESS_FUNCTION",
            "DOMAIN",
            "URL_MAPPING",
            "EMAIL",
            "CONTENT_SETTINGS",
            "HUBDB_TABLE",
            "KNOWLEDGE_BASE_ARTICLE",
            "KNOWLEDGE_BASE",
            "THEME",
            "CSS",
            "JS",
            "CTA",
            "FILE",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and object_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `object_type` ({0}), must be one of {1}".format(object_type, allowed_values))  # noqa: E501

        self._object_type = object_type

    @property
    def timestamp(self):
        """Gets the timestamp of this PublicAuditLog.  # noqa: E501

        The timestamp at which the event occurred.  # noqa: E501

        :return: The timestamp of this PublicAuditLog.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this PublicAuditLog.

        The timestamp at which the event occurred.  # noqa: E501

        :param timestamp: The timestamp of this PublicAuditLog.  # noqa: E501
        :type timestamp: datetime
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicAuditLog):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicAuditLog):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Pipelines

    Pipelines represent distinct stages in a workflow, like closing a deal or servicing a support ticket. These endpoints provide access to read and modify pipelines in HubSpot. Pipelines support `deals` and `tickets` object types.  ## Pipeline ID validation  When calling endpoints that take pipelineId as a parameter, that ID must correspond to an existing, un-archived pipeline. Otherwise the request will fail with a `404 Not Found` response.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.pipelines.api.pipeline_audits_api import PipelineAuditsApi
from hubspot.crm.pipelines.api.pipeline_stage_audits_api import PipelineStageAuditsApi
from hubspot.crm.pipelines.api.pipeline_stages_api import PipelineStagesApi
from hubspot.crm.pipelines.api.pipelines_api import PipelinesApi

# import ApiClient
from hubspot.crm.pipelines.api_client import ApiClient
from hubspot.crm.pipelines.configuration import Configuration
from hubspot.crm.pipelines.exceptions import OpenApiException
from hubspot.crm.pipelines.exceptions import ApiTypeError
from hubspot.crm.pipelines.exceptions import ApiValueError
from hubspot.crm.pipelines.exceptions import ApiKeyError
from hubspot.crm.pipelines.exceptions import ApiAttributeError
from hubspot.crm.pipelines.exceptions import ApiException

# import models into sdk package
from hubspot.crm.pipelines.models.collection_response_pipeline_no_paging import CollectionResponsePipelineNoPaging
from hubspot.crm.pipelines.models.collection_response_pipeline_stage_no_paging import CollectionResponsePipelineStageNoPaging
from hubspot.crm.pipelines.models.collection_response_public_audit_info_no_paging import CollectionResponsePublicAuditInfoNoPaging
from hubspot.crm.pipelines.models.error import Error
from hubspot.crm.pipelines.models.error_detail import ErrorDetail
from hubspot.crm.pipelines.models.pipeline import Pipeline
from hubspot.crm.pipelines.models.pipeline_input import PipelineInput
from hubspot.crm.pipelines.models.pipeline_patch_input import PipelinePatchInput
from hubspot.crm.pipelines.models.pipeline_stage import PipelineStage
from hubspot.crm.pipelines.models.pipeline_stage_input import PipelineStageInput
from hubspot.crm.pipelines.models.pipeline_stage_patch_input import PipelineStagePatchInput
from hubspot.crm.pipelines.models.public_audit_info import PublicAuditInfo



# coding: utf-8

"""
    Conversations Custom Channels

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from hubspot.conversations.custom_channels.models.channel_integration_message_egg_attachments_inner import ChannelIntegrationMessageEggAttachmentsInner
from hubspot.conversations.custom_channels.models.channel_integration_participant import ChannelIntegrationParticipant
from typing import Optional, Set
from typing_extensions import Self

class ChannelIntegrationMessageEgg(BaseModel):
    """
    ChannelIntegrationMessageEgg
    """ # noqa: E501
    message_direction: StrictStr = Field(alias="messageDirection")
    attachments: List[ChannelIntegrationMessageEggAttachmentsInner]
    recipients: List[ChannelIntegrationParticipant]
    integration_thread_id: StrictStr = Field(alias="integrationThreadId")
    integration_idempotency_id: Optional[StrictStr] = Field(default=None, alias="integrationIdempotencyId")
    text: StrictStr
    rich_text: Optional[StrictStr] = Field(default=None, alias="richText")
    channel_account_id: StrictStr = Field(alias="channelAccountId")
    senders: List[ChannelIntegrationParticipant]
    in_reply_to_id: Optional[StrictStr] = Field(default=None, alias="inReplyToId")
    timestamp: datetime
    __properties: ClassVar[List[str]] = ["messageDirection", "attachments", "recipients", "integrationThreadId", "integrationIdempotencyId", "text", "richText", "channelAccountId", "senders", "inReplyToId", "timestamp"]

    @field_validator('message_direction')
    def message_direction_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['INCOMING', 'OUTGOING']):
            raise ValueError("must be one of enum values ('INCOMING', 'OUTGOING')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChannelIntegrationMessageEgg from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item_attachments in self.attachments:
                if _item_attachments:
                    _items.append(_item_attachments.to_dict())
            _dict['attachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in recipients (list)
        _items = []
        if self.recipients:
            for _item_recipients in self.recipients:
                if _item_recipients:
                    _items.append(_item_recipients.to_dict())
            _dict['recipients'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in senders (list)
        _items = []
        if self.senders:
            for _item_senders in self.senders:
                if _item_senders:
                    _items.append(_item_senders.to_dict())
            _dict['senders'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChannelIntegrationMessageEgg from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "messageDirection": obj.get("messageDirection"),
            "attachments": [ChannelIntegrationMessageEggAttachmentsInner.from_dict(_item) for _item in obj["attachments"]] if obj.get("attachments") is not None else None,
            "recipients": [ChannelIntegrationParticipant.from_dict(_item) for _item in obj["recipients"]] if obj.get("recipients") is not None else None,
            "integrationThreadId": obj.get("integrationThreadId"),
            "integrationIdempotencyId": obj.get("integrationIdempotencyId"),
            "text": obj.get("text"),
            "richText": obj.get("richText"),
            "channelAccountId": obj.get("channelAccountId"),
            "senders": [ChannelIntegrationParticipant.from_dict(_item) for _item in obj["senders"]] if obj.get("senders") is not None else None,
            "inReplyToId": obj.get("inReplyToId"),
            "timestamp": obj.get("timestamp")
        })
        return _obj





# coding: utf-8

"""
    Hubdb

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.hubdb.configuration import Configuration


class Option(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "created_by_user_id": "int",
        "created_at": "datetime",
        "updated_by": "SimpleUser",
        "created_by": "SimpleUser",
        "name": "str",
        "id": "str",
        "label": "str",
        "updated_by_user_id": "int",
        "type": "str",
        "order": "int",
        "updated_at": "datetime",
    }

    attribute_map = {
        "created_by_user_id": "createdByUserId",
        "created_at": "createdAt",
        "updated_by": "updatedBy",
        "created_by": "createdBy",
        "name": "name",
        "id": "id",
        "label": "label",
        "updated_by_user_id": "updatedByUserId",
        "type": "type",
        "order": "order",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        created_by_user_id=None,
        created_at=None,
        updated_by=None,
        created_by=None,
        name=None,
        id=None,
        label=None,
        updated_by_user_id=None,
        type=None,
        order=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """Option - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_by_user_id = None
        self._created_at = None
        self._updated_by = None
        self._created_by = None
        self._name = None
        self._id = None
        self._label = None
        self._updated_by_user_id = None
        self._type = None
        self._order = None
        self._updated_at = None
        self.discriminator = None

        if created_by_user_id is not None:
            self.created_by_user_id = created_by_user_id
        self.created_at = created_at
        if updated_by is not None:
            self.updated_by = updated_by
        if created_by is not None:
            self.created_by = created_by
        self.name = name
        self.id = id
        if label is not None:
            self.label = label
        if updated_by_user_id is not None:
            self.updated_by_user_id = updated_by_user_id
        self.type = type
        self.order = order
        self.updated_at = updated_at

    @property
    def created_by_user_id(self):
        """Gets the created_by_user_id of this Option.  # noqa: E501


        :return: The created_by_user_id of this Option.  # noqa: E501
        :rtype: int
        """
        return self._created_by_user_id

    @created_by_user_id.setter
    def created_by_user_id(self, created_by_user_id):
        """Sets the created_by_user_id of this Option.


        :param created_by_user_id: The created_by_user_id of this Option.  # noqa: E501
        :type created_by_user_id: int
        """

        self._created_by_user_id = created_by_user_id

    @property
    def created_at(self):
        """Gets the created_at of this Option.  # noqa: E501


        :return: The created_at of this Option.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Option.


        :param created_at: The created_at of this Option.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_by(self):
        """Gets the updated_by of this Option.  # noqa: E501


        :return: The updated_by of this Option.  # noqa: E501
        :rtype: SimpleUser
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this Option.


        :param updated_by: The updated_by of this Option.  # noqa: E501
        :type updated_by: SimpleUser
        """

        self._updated_by = updated_by

    @property
    def created_by(self):
        """Gets the created_by of this Option.  # noqa: E501


        :return: The created_by of this Option.  # noqa: E501
        :rtype: SimpleUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Option.


        :param created_by: The created_by of this Option.  # noqa: E501
        :type created_by: SimpleUser
        """

        self._created_by = created_by

    @property
    def name(self):
        """Gets the name of this Option.  # noqa: E501

          # noqa: E501

        :return: The name of this Option.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Option.

          # noqa: E501

        :param name: The name of this Option.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def id(self):
        """Gets the id of this Option.  # noqa: E501

          # noqa: E501

        :return: The id of this Option.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Option.

          # noqa: E501

        :param id: The id of this Option.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def label(self):
        """Gets the label of this Option.  # noqa: E501


        :return: The label of this Option.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this Option.


        :param label: The label of this Option.  # noqa: E501
        :type label: str
        """

        self._label = label

    @property
    def updated_by_user_id(self):
        """Gets the updated_by_user_id of this Option.  # noqa: E501


        :return: The updated_by_user_id of this Option.  # noqa: E501
        :rtype: int
        """
        return self._updated_by_user_id

    @updated_by_user_id.setter
    def updated_by_user_id(self, updated_by_user_id):
        """Sets the updated_by_user_id of this Option.


        :param updated_by_user_id: The updated_by_user_id of this Option.  # noqa: E501
        :type updated_by_user_id: int
        """

        self._updated_by_user_id = updated_by_user_id

    @property
    def type(self):
        """Gets the type of this Option.  # noqa: E501

          # noqa: E501

        :return: The type of this Option.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Option.

          # noqa: E501

        :param type: The type of this Option.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def order(self):
        """Gets the order of this Option.  # noqa: E501

          # noqa: E501

        :return: The order of this Option.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this Option.

          # noqa: E501

        :param order: The order of this Option.  # noqa: E501
        :type order: int
        """
        if self.local_vars_configuration.client_side_validation and order is None:  # noqa: E501
            raise ValueError("Invalid value for `order`, must not be `None`")  # noqa: E501

        self._order = order

    @property
    def updated_at(self):
        """Gets the updated_at of this Option.  # noqa: E501


        :return: The updated_at of this Option.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Option.


        :param updated_at: The updated_at of this Option.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Option):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Option):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Automation Actions V4

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.automation.actions.configuration import Configuration


class PublicActionRevision(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"revision_id": "str", "created_at": "datetime", "definition": "PublicActionDefinition", "id": "str"}

    attribute_map = {"revision_id": "revisionId", "created_at": "createdAt", "definition": "definition", "id": "id"}

    def __init__(self, revision_id=None, created_at=None, definition=None, id=None, local_vars_configuration=None):  # noqa: E501
        """PublicActionRevision - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._revision_id = None
        self._created_at = None
        self._definition = None
        self._id = None
        self.discriminator = None

        self.revision_id = revision_id
        self.created_at = created_at
        self.definition = definition
        self.id = id

    @property
    def revision_id(self):
        """Gets the revision_id of this PublicActionRevision.  # noqa: E501


        :return: The revision_id of this PublicActionRevision.  # noqa: E501
        :rtype: str
        """
        return self._revision_id

    @revision_id.setter
    def revision_id(self, revision_id):
        """Sets the revision_id of this PublicActionRevision.


        :param revision_id: The revision_id of this PublicActionRevision.  # noqa: E501
        :type revision_id: str
        """
        if self.local_vars_configuration.client_side_validation and revision_id is None:  # noqa: E501
            raise ValueError("Invalid value for `revision_id`, must not be `None`")  # noqa: E501

        self._revision_id = revision_id

    @property
    def created_at(self):
        """Gets the created_at of this PublicActionRevision.  # noqa: E501


        :return: The created_at of this PublicActionRevision.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PublicActionRevision.


        :param created_at: The created_at of this PublicActionRevision.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def definition(self):
        """Gets the definition of this PublicActionRevision.  # noqa: E501


        :return: The definition of this PublicActionRevision.  # noqa: E501
        :rtype: PublicActionDefinition
        """
        return self._definition

    @definition.setter
    def definition(self, definition):
        """Sets the definition of this PublicActionRevision.


        :param definition: The definition of this PublicActionRevision.  # noqa: E501
        :type definition: PublicActionDefinition
        """
        if self.local_vars_configuration.client_side_validation and definition is None:  # noqa: E501
            raise ValueError("Invalid value for `definition`, must not be `None`")  # noqa: E501

        self._definition = definition

    @property
    def id(self):
        """Gets the id of this PublicActionRevision.  # noqa: E501


        :return: The id of this PublicActionRevision.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PublicActionRevision.


        :param id: The id of this PublicActionRevision.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicActionRevision):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicActionRevision):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Settings User Provisioning

    Add, manage, and remove users from your account  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.settings.users.models.collection_response_public_permission_set_no_paging import CollectionResponsePublicPermissionSetNoPaging
from hubspot.settings.users.models.collection_response_public_team_no_paging import CollectionResponsePublicTeamNoPaging
from hubspot.settings.users.models.collection_response_public_user_forward_paging import CollectionResponsePublicUserForwardPaging
from hubspot.settings.users.models.error import Error
from hubspot.settings.users.models.error_detail import ErrorDetail
from hubspot.settings.users.models.forward_paging import ForwardPaging
from hubspot.settings.users.models.next_page import NextPage
from hubspot.settings.users.models.public_permission_set import PublicPermissionSet
from hubspot.settings.users.models.public_team import PublicTeam
from hubspot.settings.users.models.public_user import PublicUser
from hubspot.settings.users.models.public_user_update import PublicUserUpdate
from hubspot.settings.users.models.user_provision_request import UserProvisionRequest



# coding: utf-8

"""
    Files

    Upload and manage files.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.files.configuration import Configuration


class FolderInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"parent_folder_id": "str", "parent_path": "str", "name": "str"}

    attribute_map = {"parent_folder_id": "parentFolderId", "parent_path": "parentPath", "name": "name"}

    def __init__(self, parent_folder_id=None, parent_path=None, name=None, local_vars_configuration=None):  # noqa: E501
        """FolderInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._parent_folder_id = None
        self._parent_path = None
        self._name = None
        self.discriminator = None

        if parent_folder_id is not None:
            self.parent_folder_id = parent_folder_id
        if parent_path is not None:
            self.parent_path = parent_path
        self.name = name

    @property
    def parent_folder_id(self):
        """Gets the parent_folder_id of this FolderInput.  # noqa: E501

        FolderId of the parent of the created folder. If not specified, the folder will be created at the root level. parentFolderId and parentFolderPath cannot be set at the same time.  # noqa: E501

        :return: The parent_folder_id of this FolderInput.  # noqa: E501
        :rtype: str
        """
        return self._parent_folder_id

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id):
        """Sets the parent_folder_id of this FolderInput.

        FolderId of the parent of the created folder. If not specified, the folder will be created at the root level. parentFolderId and parentFolderPath cannot be set at the same time.  # noqa: E501

        :param parent_folder_id: The parent_folder_id of this FolderInput.  # noqa: E501
        :type parent_folder_id: str
        """

        self._parent_folder_id = parent_folder_id

    @property
    def parent_path(self):
        """Gets the parent_path of this FolderInput.  # noqa: E501

        Path of the parent of the created folder. If not specified the folder will be created at the root level. parentFolderPath and parentFolderId cannot be set at the same time.  # noqa: E501

        :return: The parent_path of this FolderInput.  # noqa: E501
        :rtype: str
        """
        return self._parent_path

    @parent_path.setter
    def parent_path(self, parent_path):
        """Sets the parent_path of this FolderInput.

        Path of the parent of the created folder. If not specified the folder will be created at the root level. parentFolderPath and parentFolderId cannot be set at the same time.  # noqa: E501

        :param parent_path: The parent_path of this FolderInput.  # noqa: E501
        :type parent_path: str
        """

        self._parent_path = parent_path

    @property
    def name(self):
        """Gets the name of this FolderInput.  # noqa: E501

        Desired name for the folder.  # noqa: E501

        :return: The name of this FolderInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FolderInput.

        Desired name for the folder.  # noqa: E501

        :param name: The name of this FolderInput.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FolderInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FolderInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicAndFilterBranch(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "filter_branch_type": "str",
        "filter_branches": "list[PublicPropertyAssociationFilterBranchFilterBranchesInner]",
        "filter_branch_operator": "str",
        "filters": "list[PublicPropertyAssociationFilterBranchFiltersInner]",
    }

    attribute_map = {"filter_branch_type": "filterBranchType", "filter_branches": "filterBranches", "filter_branch_operator": "filterBranchOperator", "filters": "filters"}

    def __init__(self, filter_branch_type="AND", filter_branches=None, filter_branch_operator=None, filters=None, local_vars_configuration=None):  # noqa: E501
        """PublicAndFilterBranch - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._filter_branch_type = None
        self._filter_branches = None
        self._filter_branch_operator = None
        self._filters = None
        self.discriminator = None

        self.filter_branch_type = filter_branch_type
        self.filter_branches = filter_branches
        self.filter_branch_operator = filter_branch_operator
        self.filters = filters

    @property
    def filter_branch_type(self):
        """Gets the filter_branch_type of this PublicAndFilterBranch.  # noqa: E501


        :return: The filter_branch_type of this PublicAndFilterBranch.  # noqa: E501
        :rtype: str
        """
        return self._filter_branch_type

    @filter_branch_type.setter
    def filter_branch_type(self, filter_branch_type):
        """Sets the filter_branch_type of this PublicAndFilterBranch.


        :param filter_branch_type: The filter_branch_type of this PublicAndFilterBranch.  # noqa: E501
        :type filter_branch_type: str
        """
        if self.local_vars_configuration.client_side_validation and filter_branch_type is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_branch_type`, must not be `None`")  # noqa: E501
        allowed_values = ["AND"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and filter_branch_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `filter_branch_type` ({0}), must be one of {1}".format(filter_branch_type, allowed_values))  # noqa: E501

        self._filter_branch_type = filter_branch_type

    @property
    def filter_branches(self):
        """Gets the filter_branches of this PublicAndFilterBranch.  # noqa: E501


        :return: The filter_branches of this PublicAndFilterBranch.  # noqa: E501
        :rtype: list[PublicPropertyAssociationFilterBranchFilterBranchesInner]
        """
        return self._filter_branches

    @filter_branches.setter
    def filter_branches(self, filter_branches):
        """Sets the filter_branches of this PublicAndFilterBranch.


        :param filter_branches: The filter_branches of this PublicAndFilterBranch.  # noqa: E501
        :type filter_branches: list[PublicPropertyAssociationFilterBranchFilterBranchesInner]
        """
        if self.local_vars_configuration.client_side_validation and filter_branches is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_branches`, must not be `None`")  # noqa: E501

        self._filter_branches = filter_branches

    @property
    def filter_branch_operator(self):
        """Gets the filter_branch_operator of this PublicAndFilterBranch.  # noqa: E501


        :return: The filter_branch_operator of this PublicAndFilterBranch.  # noqa: E501
        :rtype: str
        """
        return self._filter_branch_operator

    @filter_branch_operator.setter
    def filter_branch_operator(self, filter_branch_operator):
        """Sets the filter_branch_operator of this PublicAndFilterBranch.


        :param filter_branch_operator: The filter_branch_operator of this PublicAndFilterBranch.  # noqa: E501
        :type filter_branch_operator: str
        """
        if self.local_vars_configuration.client_side_validation and filter_branch_operator is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_branch_operator`, must not be `None`")  # noqa: E501

        self._filter_branch_operator = filter_branch_operator

    @property
    def filters(self):
        """Gets the filters of this PublicAndFilterBranch.  # noqa: E501


        :return: The filters of this PublicAndFilterBranch.  # noqa: E501
        :rtype: list[PublicPropertyAssociationFilterBranchFiltersInner]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this PublicAndFilterBranch.


        :param filters: The filters of this PublicAndFilterBranch.  # noqa: E501
        :type filters: list[PublicPropertyAssociationFilterBranchFiltersInner]
        """
        if self.local_vars_configuration.client_side_validation and filters is None:  # noqa: E501
            raise ValueError("Invalid value for `filters`, must not be `None`")  # noqa: E501

        self._filters = filters

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicAndFilterBranch):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicAndFilterBranch):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.crm.objects.deal_splits as api_client
from ....discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def batch_api(self) -> api_client.BatchApi:
        return self._configure_api_client(api_client, "BatchApi")



# coding: utf-8

# flake8: noqa

"""
    CMS Site Search

    Use these endpoints for searching content on your HubSpot hosted CMS website(s).  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.cms.site_search.api.public_api import PublicApi

# import ApiClient
from hubspot.cms.site_search.api_client import ApiClient
from hubspot.cms.site_search.configuration import Configuration
from hubspot.cms.site_search.exceptions import OpenApiException
from hubspot.cms.site_search.exceptions import ApiTypeError
from hubspot.cms.site_search.exceptions import ApiValueError
from hubspot.cms.site_search.exceptions import ApiKeyError
from hubspot.cms.site_search.exceptions import ApiAttributeError
from hubspot.cms.site_search.exceptions import ApiException

# import models into sdk package
from hubspot.cms.site_search.models.content_search_result import ContentSearchResult
from hubspot.cms.site_search.models.error import Error
from hubspot.cms.site_search.models.error_detail import ErrorDetail
from hubspot.cms.site_search.models.indexed_data import IndexedData
from hubspot.cms.site_search.models.indexed_field import IndexedField
from hubspot.cms.site_search.models.public_search_results import PublicSearchResults
